==> spice-up-1.8.2-3.src.tar.gz: Spice-up-1.8.2/.github/ISSUE_TEMPLATE.md <==
<!--- Thank you for making a bug repport! This allows us to make the app even better. -->
<!--- Filling out the folowing information will help us reproduce and fix the problem faster. -->

## Expected Behavior
<!--- If you're describing a bug, tell us what should happen -->
<!--- If you're suggesting a change/improvement, tell us how it should work -->

## Current Behavior
<!--- If describing a bug, tell us what happens instead of the expected behavior -->
<!--- If suggesting a change/improvement, explain the difference from current behavior -->

## Possible Solution
<!--- Not obligatory, but suggest a fix/reason for the bug, -->
<!--- or ideas how to implement the addition or change -->

## Steps to Reproduce (for bugs)
<!--- Help us reproduce the issue by providing us a set of steps to reproduce this bug -->
1.
2.
3.
4.

## Context
<!--- How has this issue affected you? What are you trying to accomplish? -->
<!--- Providing context helps us come up with a solution that is most useful in the real world -->
<!--- If you have a terminal output you can share with us that would also be great! -->

<!--- To get debug messages: G_MESSAGES_DEBUG=all com.github.philip-scott.spice-up -->

<!--- Sharing the .spice file where the problem is at will also be super helpful. -->

## Screenshots of the Problem
<!--- If you can show us a screenshot of the issue, this is the space for it! -->
<!--- If you're suggesting a feature and can give us a mockup, that would also be great! -->

## Your Environment (for bugs)
<!--- Include as many relevant details about the environment you experienced the bug in -->
<!--- If you can also run the folowing command and put the output here, that would be super helpful!  -->
<!---                   uname -a && cat /etc/os-release          -->

- Spice-Up Version: <!-- From Release, or Commit if compiled from source -->
- OS Info:

==> spice-up-1.9.1-3.src.tar.gz: Spice-up-1.9.1/.github/ISSUE_TEMPLATE.md <==
<!--- Thank you for making a bug report! This allows us to make the app even better. -->
<!--- Filling out the following information will help us reproduce and fix the problem faster. -->

## Expected Behavior
<!--- If you're describing a bug, tell us what should happen -->
<!--- If you're suggesting a change/improvement, tell us how it should work -->

## Current Behavior
<!--- If describing a bug, tell us what happens instead of the expected behavior -->
<!--- If suggesting a change/improvement, explain the difference from current behavior -->

## Possible Solution
<!--- Not obligatory, but suggest a fix/reason for the bug, -->
<!--- or ideas how to implement the addition or change -->

## Steps to Reproduce (for bugs)
<!--- Help us reproduce the issue by providing us a set of steps to reproduce this bug -->
1.
2.
3.
4.

## Context
<!--- How has this issue affected you? What are you trying to accomplish? -->
<!--- Providing context helps us come up with a solution that is most useful in the real world -->
<!--- If you have a terminal output you can share with us that would also be great! -->

<!--- To get debug messages: G_MESSAGES_DEBUG=all com.github.philip_scott.spice-up -->

<!--- Sharing the .spice file where the problem is at will also be super helpful. -->

## Screenshots of the Problem
<!--- If you can show us a screenshot of the issue, this is the space for it! -->
<!--- If you're suggesting a feature and can give us a mockup, that would also be great! -->

## Your Environment (for bugs)
<!--- Include as many relevant details about the environment you experienced the bug in -->
<!--- If you can also run the following command and put the output here, that would be super helpful!  -->
<!---                   uname -a && cat /etc/os-release          -->


```
<!--- Also, to avoid tagging other issues or pull requests, please keep this info inside of the ``` tags, thank you! ->

- Spice-Up Version: <!-- From Release, or Commit if compiled from source -->
- OS Info:

```
